@@ -34,6 +34,7 @@ from rospkg.os_detect import OS_RHEL, OS_FEDORA
 
 from .source import SOURCE_INSTALLER
 from ..installers import PackageManagerInstaller
+from ..shell_utils import read_stdout
 
 # yum package manager key
 YUM_INSTALLER='yum'
@@ -55,14 +56,16 @@ def register_rhel(context):
     context.add_os_installer_key(OS_RHEL, SOURCE_INSTALLER)
     context.set_default_os_installer_key(OS_RHEL, YUM_INSTALLER)
 
-def rpm_detect(packages):
+def rpm_detect(packages, exec_fn=None):
     ret_list = []
     #cmd = ['rpm', '-q', '--qf ""']  # suppress output for installed packages
     cmd = ['rpm', '-q', '--qf', '%{NAME}\n']  # output: "pkg_name" for installed, error text for not installed packages
-    cmd.extend(pkgs)
+    cmd.extend(packages)
 
-    pop = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-    (std_out, std_err) = pop.communicate()
+    if exec_fn is None:
+        exec_fn = read_stdout
+
+    std_out = exec_fn(cmd)
     out_lines = std_out.split('\n')
     for line in out_lines:
         # if there is no space, it's not an error text -> it's installed
